==> zio-aws-ec2_2.12-5.17.152.1-sources.jar: zio/aws/ec2/model/TrunkInterfaceAssociation.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, TrunkInterfaceAssociationId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TrunkInterfaceAssociation(
    associationId: Option[TrunkInterfaceAssociationId] = None,
    branchInterfaceId: Option[String] = None,
    trunkInterfaceId: Option[String] = None,
    interfaceProtocol: Option[zio.aws.ec2.model.InterfaceProtocolType] = None,
    vlanId: Option[Integer] = None,
    greKey: Option[Integer] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation = {
    import TrunkInterfaceAssociation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
      .builder()
      .optionallyWith(
        associationId.map(value =>
          TrunkInterfaceAssociationId.unwrap(value): java.lang.String
        )
      )(_.associationId)
      .optionallyWith(branchInterfaceId.map(value => value: java.lang.String))(
        _.branchInterfaceId
      )
      .optionallyWith(trunkInterfaceId.map(value => value: java.lang.String))(
        _.trunkInterfaceId
      )
      .optionallyWith(interfaceProtocol.map(value => value.unwrap))(
        _.interfaceProtocol
      )
      .optionallyWith(vlanId.map(value => value: java.lang.Integer))(_.vlanId)
      .optionallyWith(greKey.map(value => value: java.lang.Integer))(_.greKey)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.TrunkInterfaceAssociation.ReadOnly =
    zio.aws.ec2.model.TrunkInterfaceAssociation.wrap(buildAwsValue())
}
object TrunkInterfaceAssociation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TrunkInterfaceAssociation =
      zio.aws.ec2.model.TrunkInterfaceAssociation(
        associationId.map(value => value),
        branchInterfaceId.map(value => value),
        trunkInterfaceId.map(value => value),
        interfaceProtocol.map(value => value),
        vlanId.map(value => value),
        greKey.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def associationId: Option[TrunkInterfaceAssociationId]
    def branchInterfaceId: Option[String]
    def trunkInterfaceId: Option[String]
    def interfaceProtocol: Option[zio.aws.ec2.model.InterfaceProtocolType]
    def vlanId: Option[Integer]
    def greKey: Option[Integer]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getAssociationId: ZIO[Any, AwsError, TrunkInterfaceAssociationId] =
      AwsError.unwrapOptionField("associationId", associationId)
    def getBranchInterfaceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("branchInterfaceId", branchInterfaceId)
    def getTrunkInterfaceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("trunkInterfaceId", trunkInterfaceId)
    def getInterfaceProtocol
        : ZIO[Any, AwsError, zio.aws.ec2.model.InterfaceProtocolType] =
      AwsError.unwrapOptionField("interfaceProtocol", interfaceProtocol)
    def getVlanId: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("vlanId", vlanId)
    def getGreKey: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("greKey", greKey)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
  ) extends zio.aws.ec2.model.TrunkInterfaceAssociation.ReadOnly {
    override val associationId: Option[TrunkInterfaceAssociationId] = scala
      .Option(impl.associationId())
      .map(value =>
        zio.aws.ec2.model.primitives.TrunkInterfaceAssociationId(value)
      )
    override val branchInterfaceId: Option[String] =
      scala.Option(impl.branchInterfaceId()).map(value => value: String)
    override val trunkInterfaceId: Option[String] =
      scala.Option(impl.trunkInterfaceId()).map(value => value: String)
    override val interfaceProtocol
        : Option[zio.aws.ec2.model.InterfaceProtocolType] = scala
      .Option(impl.interfaceProtocol())
      .map(value => zio.aws.ec2.model.InterfaceProtocolType.wrap(value))
    override val vlanId: Option[Integer] =
      scala.Option(impl.vlanId()).map(value => value: Integer)
    override val greKey: Option[Integer] =
      scala.Option(impl.greKey()).map(value => value: Integer)
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
  ): zio.aws.ec2.model.TrunkInterfaceAssociation.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.124.3-sources.jar: zio/aws/ec2/model/TrunkInterfaceAssociation.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, TrunkInterfaceAssociationId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TrunkInterfaceAssociation(
    associationId: Option[TrunkInterfaceAssociationId] = None,
    branchInterfaceId: Option[String] = None,
    trunkInterfaceId: Option[String] = None,
    interfaceProtocol: Option[zio.aws.ec2.model.InterfaceProtocolType] = None,
    vlanId: Option[Integer] = None,
    greKey: Option[Integer] = None,
    tags: Option[Iterable[zio.aws.ec2.model.Tag]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation = {
    import TrunkInterfaceAssociation.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
      .builder()
      .optionallyWith(
        associationId.map(value =>
          TrunkInterfaceAssociationId.unwrap(value): java.lang.String
        )
      )(_.associationId)
      .optionallyWith(branchInterfaceId.map(value => value: java.lang.String))(
        _.branchInterfaceId
      )
      .optionallyWith(trunkInterfaceId.map(value => value: java.lang.String))(
        _.trunkInterfaceId
      )
      .optionallyWith(interfaceProtocol.map(value => value.unwrap))(
        _.interfaceProtocol
      )
      .optionallyWith(
        vlanId.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.vlanId)
      .optionallyWith(
        greKey.map(value => Integer.unwrap(value): java.lang.Integer)
      )(_.greKey)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.TrunkInterfaceAssociation.ReadOnly =
    zio.aws.ec2.model.TrunkInterfaceAssociation.wrap(buildAwsValue())
}
object TrunkInterfaceAssociation {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.TrunkInterfaceAssociation =
      zio.aws.ec2.model.TrunkInterfaceAssociation(
        associationId.map(value => value),
        branchInterfaceId.map(value => value),
        trunkInterfaceId.map(value => value),
        interfaceProtocol.map(value => value),
        vlanId.map(value => value),
        greKey.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def associationId: Option[TrunkInterfaceAssociationId]
    def branchInterfaceId: Option[String]
    def trunkInterfaceId: Option[String]
    def interfaceProtocol: Option[zio.aws.ec2.model.InterfaceProtocolType]
    def vlanId: Option[Integer]
    def greKey: Option[Integer]
    def tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def getAssociationId: ZIO[Any, AwsError, TrunkInterfaceAssociationId] =
      AwsError.unwrapOptionField("associationId", associationId)
    def getBranchInterfaceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("branchInterfaceId", branchInterfaceId)
    def getTrunkInterfaceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("trunkInterfaceId", trunkInterfaceId)
    def getInterfaceProtocol
        : ZIO[Any, AwsError, zio.aws.ec2.model.InterfaceProtocolType] =
      AwsError.unwrapOptionField("interfaceProtocol", interfaceProtocol)
    def getVlanId: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("vlanId", vlanId)
    def getGreKey: ZIO[Any, AwsError, Integer] =
      AwsError.unwrapOptionField("greKey", greKey)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
  ) extends zio.aws.ec2.model.TrunkInterfaceAssociation.ReadOnly {
    override val associationId: Option[TrunkInterfaceAssociationId] = scala
      .Option(impl.associationId())
      .map(value =>
        zio.aws.ec2.model.primitives.TrunkInterfaceAssociationId(value)
      )
    override val branchInterfaceId: Option[String] =
      scala.Option(impl.branchInterfaceId()).map(value => value: String)
    override val trunkInterfaceId: Option[String] =
      scala.Option(impl.trunkInterfaceId()).map(value => value: String)
    override val interfaceProtocol
        : Option[zio.aws.ec2.model.InterfaceProtocolType] = scala
      .Option(impl.interfaceProtocol())
      .map(value => zio.aws.ec2.model.InterfaceProtocolType.wrap(value))
    override val vlanId: Option[Integer] = scala
      .Option(impl.vlanId())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val greKey: Option[Integer] = scala
      .Option(impl.greKey())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val tags: Option[List[zio.aws.ec2.model.Tag.ReadOnly]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.ec2.model.Tag.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.TrunkInterfaceAssociation
  ): zio.aws.ec2.model.TrunkInterfaceAssociation.ReadOnly = new Wrapper(impl)
}
